#[non_exhaustive]#[repr(u32)]pub enum Action {
None = 0,
Submit = 1,
}Expand description
action
A possible action to perform on a text input.
The submit action is intended for input entries that expect some sort of activation after user interaction, e.g. the URL entry in a browser.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.