#[non_exhaustive]pub struct Action(pub u32);Expand description
action
A possible action to perform on a text input.
The submit action is intended for input entries that expect some sort of activation after user interaction, e.g. the URL entry in a browser.
Tuple Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.0: u32Implementations